@@ -1,15 +1,30 @@
 import os
-from numpy import e
 import pandas as pd
-import csv
+from sqlalchemy.sql.elements import Null
 import LibHanger.Library.uwGetter as Getter
 from pandas.core.frame import DataFrame
 from LibHanger.Library.uwExport import ExcelImporter
 
 class modelGenerator(ExcelImporter):
     
+    """ 
+    Modelジェネレータークラス
+    """
+    
     def __init__(self) -> None:
+        
+        """
+        コンストラクタ
+
+        Parameters
+        ----------
+        None
+        
+        """
+        
         super().__init__()
+        
+        # フィールド型の対応クラス及びカラムタイプ定義
         self.fieldTypeMap = {
              'varchar':{'method':'CharFields','columnType':'String'}
             ,'numeric':{'method':'NumericFields','columnType':'Numeric'}
@@ -21,6 +36,15 @@ class modelGenerator(ExcelImporter):
         
     def put_modelByCsv(self):
         
+        """
+        モデル⇒Csvファイル出力
+
+        Parameters
+        ----------
+        None
+        
+        """
+        
         for sheetname in self.sheets:
             if str(sheetname).startswith(('trn','mst')): 
                 # テーブル定義をDataFrameで取得
@@ -28,8 +52,17 @@ class modelGenerator(ExcelImporter):
                 # Model内容をpythonファイル出力
                 self.put_modelPython(df, sheetname)
                    
-    def get_TableDefByDataFrame(self, sheetname):
+    def get_TableDefByDataFrame(self, sheetname:str):
         
+        """
+        テーブル定義シートをDataFrameに変換
+        
+        Parameters
+        ----------
+        sheetname : str
+            読込対象シート名
+        """
+
         # シートをdict型に変換
         dict = pd.read_excel(self.filepath, sheet_name=sheetname, skiprows=8, usecols=[1,12,13,14,15,16])
         # dict->DataFrame
@@ -47,13 +80,25 @@ class modelGenerator(ExcelImporter):
     
     def put_modelPython(self, df:DataFrame, sheetname:str):
         
+        """
+        ModelをPythonファイルに出力
+        
+        Parameters
+        ----------
+        df : DataFrame
+            対象DataFrame
+        sheetname : str
+            読込対象シート名
+        """
+        
         # 出力先パス取得
         output_dir = os.path.dirname(self.filepath)
         
         # pythonファイル出力
         with open(os.path.join(output_dir, sheetname + '.py'), 'w', newline='', encoding='utf-8') as f:
-            f.writelines('from sqlalchemy.ext.declarative import declarative_base\n')
             f.writelines('import LibHanger.Models.fields as fld\n')
+            f.writelines('from sqlalchemy.ext.declarative import declarative_base\n')
+            f.writelines('from sqlalchemy.sql.elements import Null\n')
             f.writelines('\n')
             f.writelines('# Baseクラス生成\n')
             f.writelines('Base = declarative_base()\n')
@@ -71,11 +116,32 @@ class modelGenerator(ExcelImporter):
         f.close()
         
     def get_fieldType_val(self, defRow, valType):
+        
+        """
+        テーブル定義のデータ型に対応するColumnType取得
+        
+        Parameters
+        ----------
+        defRow : Any
+            対象Series
+        valType : Any
+            データ型
+        """
+        
         fieldTypeVal:dict = self.fieldTypeMap.get(defRow['datatype'])
         return fieldTypeVal.get(valType)
         
     def get_fieldType_args(self, defRow):
         
+        """
+        Columnクラスに渡すパラメーター取得
+        
+        Parameters
+        ----------
+        defRow : Any
+            対象Series
+        """
+
         # フィールドタイプ設定
         dataType:str = defRow['datatype']
         if dataType == 'varchar':
@@ -96,20 +162,15 @@ class modelGenerator(ExcelImporter):
             fieldType.append(primary_key)
         # 既定値設定
         if defRow['default'] != None:
-            if dataType == 'varchar':               
-                defaultFormat = 'default=\'{0}\''
-            else:
-                defaultFormat = 'default={0}'
-                
-            if defRow['default'] == 'NUL':
-                default = 'None'
-            elif defRow['default'] == '':
-                if dataType == 'varchar':
-                    default = ''
-                else:
-                    default = 'None'
-            else:
-                default = str(int(defRow['default']))
+            
+            # 既定値書式
+            defaultFormat = 'default=\'{0}\'' if dataType == 'varchar' and defRow['default'] != 'NUL' else 'default={0}'
+            
+            # 既定値の値
+            default = 'Null' if defRow['default'] == 'NUL' \
+                 else '' if defRow['default'] == '' and dataType == 'varchar' \
+                 else 'Null' if defRow['default'] == '' and dataType != 'varchar' \
+                 else str(int(defRow['default']))
             fieldType.append(defaultFormat.format(default))
         return Getter.getListMargeString(',', fieldType)
 
